@@ -37,12 +37,20 @@ if( !is_readable( $cgextensions ) )
 require_once($cgextensions);
 
 define('CGGM_PREF_NEWMAP_TEMPLATE','cggm_pref_newmap_template');
+define('CGGM_PREF_NEWSIEBAR_TEMPLATE','cggm_pref_newsidebar_template');
+define('CGGM_PREF_NEWCATEGORY_TEMPLATE','cggm_pref_newcategory_template');
 define('CGGM_PREF_DFLTMAP_TEMPLATE','cggm_pref_dfltmap_template');
+define('CGGM_NEWJS_TEMPLATE','cggm_newjs_template');
+define('CGGM_NEWSIDEBAR_TEMPLATE','cggm_newsidebar_template');
+define('CGGM_NEWCATEGORY_TEMPLATE','cggm_newcategory_template');
+define('CGGM_NEWDIRFORM_TEMPLATE','cggm_newdirform_template');
 
-/*---------------------------------------------------------
- cggm_add_dynpoint()
- ---------------------------------------------------------*/
-function cggm_add_dynpoint($params, &$smarty)
+/**
+ * Add a category to the map.
+ *
+ * @ignore
+ */
+function cggm_add_category($params, &$smarty)
 {
   $map = '';
   if( isset($params['map']) )
@@ -55,6 +63,60 @@ function cggm_add_dynpoint($params, &$smarty)
       $mod =& $gCms->modules['CGGoogleMaps']['object'];
       $map = $mod->GetPreference('default_map',0);
    }
+
+  if( !isset($params['name']) )
+    {
+      // name is required
+      return; 
+    }
+  $name = $params['name'];
+  
+  $key = $name;
+  if( isset($params['key']) )
+    {
+      $key = trim($params['name']);
+    }
+
+  $description = '';
+  if( isset($params['desc']) )
+    {
+      $description = $params['desc'];
+    }
+  if( isset($params['description']) )
+    {
+      $description = $params['description'];
+    }
+  
+  $icon = '';
+  if( isset($params['icon']) )
+    {
+      $icon = $params['icon'];
+    }
+
+  $mod = cge_utils::get_module('CGGoogleMaps');
+  $obj = new cggm_category($name,$key);
+  $obj->set_description($description);
+  $obj->set_icon($icon);
+  $mod->add_map_category($map,$obj);
+}
+
+
+/*---------------------------------------------------------
+ cggm_add_dynpoint()
+ ---------------------------------------------------------*/
+function cggm_add_dynpoint($params, &$smarty)
+{
+  $mod = cge_utils::get_module('CGGoogleMaps');
+  if( !$mod ) return;
+  $map = '';
+  if( isset($params['map']) )
+    {
+      $map = $params['map'];
+    }
+  else
+    {
+      $map = $mod->GetPreference('default_map',0);
+    }
   
   if( !isset($params['name']) )
     {
@@ -97,10 +159,19 @@ function cggm_add_dynpoint($params, &$smarty)
       $icon = $params['icon'];
     }
 
-  global $gCms;
-  $mod =& $gCms->modules['CGGoogleMaps']['object'];
-  $mod->AddDynamicPoint($map,$name,$description,
-			$address,$lat,$long,$icon);
+  $obj = new cggm_marker($name,$address,$lat,$long,$icon);
+  $obj->set_description($description);
+  if( isset($params['category']) )
+    {
+      $tmp = trim($params['category']);
+      if( $tmp )
+	{
+	  $obj->add_category(trim($tmp));
+	}
+    }
+
+  if( isset($params['tooltip']) )  $obj->set_tooltip($params['tooltip']);
+  $mod->add_map_point($map,$obj);
 }
 
 
@@ -108,6 +179,7 @@ function cggm_add_dynpoint($params, &$smarty)
 class CGGoogleMaps extends CGExtensions
 {
   var $_dynamic_points;
+  var $_dyn_categories;
 
   /*---------------------------------------------------------
    CGGoogleMaps() -- Constructor
@@ -145,7 +217,7 @@ class CGGoogleMaps extends CGExtensions
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.4.2';
+    return '2.0.3';
   }
 
 
@@ -181,7 +253,7 @@ class CGGoogleMaps extends CGExtensions
    ---------------------------------------------------------*/
   function GetChangeLog()
   {
-    return $this->Lang('changelog');
+    return file_get_contents(dirname(__FILE__).'/changelog.inc');
   }
   
   /*---------------------------------------------------------
@@ -254,7 +326,7 @@ EOT;
    ---------------------------------------------------------*/
   function GetDependencies()
   {
-    return array('CGExtensions'=>'1.19.4',
+    return array('CGExtensions'=>'1.21.5',
 		 'CGSimpleSmarty'=>'1.4');
   }
 
@@ -264,7 +336,7 @@ EOT;
    ---------------------------------------------------------*/
   function MinimumCMSVersion()
   {
-    return "1.6.6";
+    return "1.8.2";
   }
 	
 	
@@ -380,8 +452,7 @@ EOT;
     $southmost  = asin(sin($lat_r) * cos($distance_in_miles/$radius) + cos($lat_r) * sin ($distance_in_miles/$radius) * cos($due_south));
 		
     $eastmost = $lon_r + atan2(sin($due_east)*sin($distance_in_miles/$radius)*cos($lat_r),cos($distance_in_miles/$radius)-sin($lat_r)*sin($lat_r));
-    $westmost = $lon_r + atan2(sin($due_west)*sin($distance_in_miles/$radius)*cos($lat_r),cos($distance_in_miles/$radius)-sin($lat_r)*sin($lat_r));
-			
+    $westmost = $lon_r + atan2(sin($due_west)*sin($distance_in_miles/$radius)*cos($lat_r),cos($distance_in_miles/$radius)-sin($lat_r)*sin($lat_r));			
 			
     $northmost = rad2deg($northmost);
     $southmost = rad2deg($southmost);
@@ -411,7 +482,8 @@ EOT;
     return array($lat1,$lat2,$lon1,$lon2);
   }
 
-  function AddDynamicPoint($map,$name,$description,$address='',$lat='',$long='',$icon='')
+function AddDynamicPoint($map,$name,$description,$address='',$lat='',$long='',$icon='',$tooltip = '',
+			 $sidebar_class = '',$sidebar_html = '')
   {
     if( empty($map) ) return FALSE;
     if( empty($name) ) return FALSE;
@@ -427,29 +499,43 @@ EOT;
       }
 
     // everything is good to go, build the point object.
-    $obj = new StdClass;
-    $obj->name = $name;
-    $obj->description = $description;
-    $obj->icon = $icon;
-    if( !empty($address) )
+    $obj = new cggm_marker($name,$address,$lat,$long,$icon);
+    $obj->set_description($description);
+    $this->add_map_point($map,$obj);
+  }
+
+
+  public function add_map_point($map,cggm_marker& $obj)
+  {
+    // todo, convert map name to a map id here.
+    $map = (int)$map;
+    if( !is_array($this->_dynamic_points) )
       {
-	$obj->address = $address;
+	$this->_dynamic_points = array();
       }
-    else if( !empty($lat) && !empty($long) )
+    if( !isset($this->_dynamic_points[$map]) )
       {
-	$obj->lat = $lat;
-	$obj->long = $long;
-      }
-    else
-      {
-	return FALSE;
+	$this->_dynamic_points[$map] = array();
       }
 
-    // add the point to the list
     $this->_dynamic_points[$map][] = $obj;
   }
 
 
+  public function add_map_category($map,cggm_category& $obj)
+  {
+    if( $map == '' ) return FALSE;
+    if( !is_array($this->_dyn_categories) )
+      {
+	$this->_dyn_categories = array();
+      }
+    if( !isset($this->_dyn_categories[$map]) )
+      {
+	$this->_dyn_categories[$map] = array();
+      }
+
+    $this->_dyn_categories[$map][] = $obj;
+  }
 } // class
 
 ?>
